@@ -5,6 +5,6 @@ from .annotation import *
 from .calibration import *
 from .files_to_upload import *
 from .input import *
-from .project import *
+from .projects import *
 from .upload_url import *
 from .ego import *
\ No newline at end of file
