@@ -42,11 +42,11 @@ class LidarsAndCameras(CreateableInputAPIResource):
 
         payload = lidars_and_cameras.to_dict()
 
-        response = self.post_input_request(self.path, payload,
-                                           project=project,
-                                           batch=batch,
-                                           input_list_id=input_list_id,
-                                           dryrun=dryrun)
+        response = self._post_input_request(self.path, payload,
+                                            project=project,
+                                            batch=batch,
+                                            input_list_id=input_list_id,
+                                            dryrun=dryrun)
 
         if dryrun:
             return None
